@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,7 +15,7 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 # Notes: we use instances of these objects as singletons which serve as
 # identifiers in various patches of code.  The more specific types
@@ -25,7 +25,6 @@ from __future__ import division, print_function, absolute_import
 
 
 class UniqueIdentifier(object):
-
     def __init__(self, identifier):
         self.identifier = identifier
 
@@ -41,5 +40,5 @@ class InferType(UniqueIdentifier):
     pass
 
 
-infer = InferType(u'infer')
-not_set = UniqueIdentifier(u'not_set')
+infer = InferType(u"infer")
+not_set = UniqueIdentifier(u"not_set")
